% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PeriodStandardization.R
\name{CST_PeriodStandardization}
\alias{CST_PeriodStandardization}
\title{Compute the Standardization of Precipitation-Evapotranspiration Index}
\usage{
CST_PeriodStandardization(
  data,
  data_cor = NULL,
  time_dim = "syear",
  leadtime_dim = "time",
  memb_dim = "ensemble",
  accum = NULL,
  ref_period = NULL,
  param_error = -9999,
  handle_infinity = FALSE,
  method = "parametric",
  distribution = "log-Logistic",
  na.rm = FALSE,
  ncores = NULL
)
}
\arguments{
\item{data}{An 's2dv_cube' that element 'data' stores a multidimensional 
array containing the data to be standardized.}

\item{data_cor}{An 's2dv_cube' that element 'data' stores a multidimensional 
array containing the data in which the standardization should be applied 
using the fitting parameters from 'data'.}

\item{time_dim}{A character string indicating the name of the temporal 
dimension. By default, it is set to 'syear'.}

\item{leadtime_dim}{A character string indicating the name of the temporal 
dimension. By default, it is set to 'time'.}

\item{memb_dim}{A character string indicating the name of the dimension in 
which the ensemble members are stored. When set it to NULL, threshold is 
computed for individual members.}

\item{accum}{An integer value indicating the number of months for the 
accumulation for each variable. When it is greater than 1, the result will 
be filled with NA until the accum time_dim dimension number due to the 
accumulation to previous months.}

\item{ref_period}{A list with two numeric values with the starting and end 
points of the reference period used for computing the index. The default 
value is NULL indicating that the first and end values in data will be 
used as starting and end points.}

\item{param_error}{A numeric value with the error accepted.}

\item{handle_infinity}{A logical value wether to return Infinite values (TRUE)
or not (FALSE).}

\item{method}{A character string indicating the standardization method used. 
If can be: 'parametric' or 'non-parametric'. It is set to 'parametric' by 
default.}

\item{distribution}{A character string indicating the name of the distribution 
function to be used for computing the SPEI. The accepted names are: 
'log-Logistic' and 'Gamma'. It is set to 'log-Logistic' by default. The 
'Gamma' method only works when only precipitation is provided and other 
variables are 0 because it is positive defined (SPI indicator).}

\item{na.rm}{A logical value indicating whether NA values should be removed 
from data. It is FALSE by default. If it is FALSE and there are NA values, 
(if standardization is TRUE) all values of other dimensions except time_dim 
and leadtime_dim will be set to NA directly. On the other hand, if it is 
TRUE, if the data from other dimensions except time_dim and leadtime_dim is 
not reaching 4 values, it is not enough values to estimate the parameters 
and the result will include NA.}

\item{ncores}{An integer value indicating the number of cores to use in 
parallel computation.}
}
\value{
An object of class \code{s2dv_cube} containing the standardized data. 
If 'data_cor' is provided the standardizaton is applied to it using 'data' 
to adjust it.
}
\description{
Compute the Standardization of Precipitation-Evapotranspiration Index
}
\examples{
dims <-  c(syear = 6, time = 3, latitude = 2, ensemble = 25)
data <- NULL
data$data <- array(rnorm(600, -204.1, 78.1), dim = dims)
class(data) <- 's2dv_cube'
SPEI <- CST_PeriodStandardization(data = data, accum = 2)
}
